#!/bin/sh
#  em.reg [-d] [-u] [em module to test] [em options]

# TEST CASE BREAKDOWN:
#  Level 1:
#     - Standard
#     - Standard - quade precision (Automatically detected)
#  Level 2:
#     - MRs
#  Level 3:
#     - User files
#  Level 4:
#     - Long runs (MR plus user files)


# Set SDIFF to ssdiff, if not available set to diff
# SDIFF=ssdiff
 SDIFF=diff
export SDIFF

MAKE_DOS_SCRIPT=FALSE;	export MAKE_DOS_SCRIPT
UPDATE_TESTCASE=FALSE;	export UPDATE_TESTCASE
DIAGNOSTIC_LEVEL=1;	export DIAGNOSTIC_LEVEL
MAKE_JXY=FALSE;		export MAKE_JXY

# Supply all options on next line
set -- `getopt jhdul: $*`

# Check if correct option was given
if [ $? != 0 ]
then
	echo "$USAGE" >&2
	exit 1
fi

for opt in $*
do
        case $opt in

        -h )    # Help option
                cat <<-!!
			-d	make dos test script
			-u	udpates all test cases
			-l n	Run diagnostics level n:
			          1 - basic test only - Default
			          2 - also include mrs
			          3 - also include customer circuits
			          4 - also include long running problems
		!!
		exit 1
		;;
	-d)	# make dos script
		MAKE_DOS_SCRIPT=TRUE
		shift
		;;
	-u)	# update all test cases results
		UPDATE_TESTCASE=TRUE
		shift
		;;
	-j)	# produce jxy files
		MAKE_JXY=TRUE
		shift
		;;
	-l)	# Set diagnotics level
		DIAGNOSTIC_LEVEL=$2
		shift; shift
		;;
	--)
		shift
		break
		;;   

	-*)     # Option is defined in getopt(1) but not in the case statement
		echo "Internal Error: option $1 not handled correctly." >&2
		exit 2
		;;
	esac
done

#######
####### Check for EM modules name
#######
if [ "$1" = "" ]
then
	if [ "$LOGNAME" = rautio ]
	then
		EM="../em/em"; export EM
	else
		EM="$MFG/sonnet/bin/em"; export EM
	fi
else
	EM="$1"; export EM
fi

#######
####### Check for EM options
#######
if [ "$2" = "" ]
then
	OPTS=""
else
	OPTS="$2"
fi
export OPTS

#######
####### Set diagnostic level
#######
BASIC_TEST=FALSE;		export BASIC_TEST
MR_TEST=FALSE;			export MR_TEST
CUSTOMER_FILE_TEST=FALSE;	export CUSTOMER_FILE_TEST
LONG_TEST=FALSE;		export LONG_TEST
case $DIAGNOSTIC_LEVEL
in
	1)	BASIC_TEST=TRUE 
		;;
	2)	BASIC_TEST=TRUE
		MR_TEST=TRUE
		;;
	3)	BASIC_TEST=TRUE
		MR_TEST=TRUE
		CUSTOMER_FILE_TEST=TRUE
		;;
	4)	BASIC_TEST=TRUE
		MR_TEST=TRUE
		CUSTOMER_FILE_TEST=TRUE
		LONG_TEST=TRUE
		;;
	*)	echo "Invalid diagnostic level $DIAGNOSTIC_LEVEL" >&2
		echo "Must be between 1 and 4" >&2
		exit 1
	
esac

#######
####### Set env. variables.
#######

GEO=geo; export GEO
RSP=rsp; export RSP

# Determine version of EM
EM_VERSION=`$EM -Ver`
export EM_VERSION

rm -f cir.rsp
mv result oldresult 2> /dev/null

date >> result
echo "Executing EM: $EM $OPTS" >> result
echo >> result

rm -f  summary cir.rsp

if [ "$MAKE_DOS_SCRIPT" = TRUE ]
then
	{
	echo "@echo off"
	echo "c:\bin\date > result.dos"
	} > emreg.bat
fi

#######
####### 		TEST CASES FOR EM
#######

if [ $BASIC_TEST = TRUE ]
then
	emtests BASIC_TEST
fi

if [ $MR_TEST = TRUE ]
then
	emtests MR_TEST
fi

if [ $CUSTOMER_FILE_TEST = TRUE ]
then
	emtests CUSTOMER_FILE_TEST
fi

if [ $LONG_TEST = TRUE ]
then
	emtests LONG_TEST
fi

#####

echo "-- Finished with regression test 2 for em." >>result
date >>result

if [ "$MAKE_DOS_SCRIPT" = TRUE ]
then
	{
	echo "echo -- Finished with regression test for em."
	echo "c:\bin\date >> result.dos"
	echo "Results are in result.dos"
	} >> emreg.bat
	unix2dos emreg.bat > tmp1
	mv tmp1 emreg.bat
fi

# Cleanup work
rm -f testa testb

echo -- Finshed with regression test 2 for em.
date
